/***************************************************************************
                          kurd.cpp  -  description
                             -------------------
    begin                : Fri Feb 14 15:15:40 CST 2003
    copyright            : (C) 2003 by David Monk
    email                : dmonk@purplebear.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kmessagebox.h>
#include <kiconloader.h>
#include <qfont.h>
#include <qtooltip.h>
#include <stdlib.h>

#include "kurd.moc"

Kurd::Kurd()
{
	setMinimumWidth(500);
	setMaximumWidth(500);
	setMinimumHeight(160);
	setMaximumHeight(160);
	setCaption("Kurd");

	QRect scr = QApplication::desktop()->screenGeometry();
	move(scr.center() - rect().center());
	
	bannerLabel = new QLabel(this, "bannerlabel");
	bannerLabel->setGeometry(0,0,500,75);
	bannerLabel->setPixmap(QPixmap::fromMimeSource("banner.png"));
	bannerLabel->setScaledContents(TRUE);
	
	lineLabel = new QLabel(this, "linelabel");
	lineLabel->setText("Server:");
	lineLabel->setGeometry(25,80,50,30);
	lineLabel->show();

	serverName = new QComboBox(TRUE, this, "servername");
	serverName->setGeometry(80,80,395,30);
	serverName->setCurrentText("Remote Server");
	serverName->setAutoCompletion(TRUE);
	serverName->setDuplicatesEnabled(FALSE);
	QToolTip::add(serverName, "Specify to hostname or IP address to connect to. If using vncviewer, also specify the port.");
	serverName->show();
	serverName->setFocus();

	
	btnConnect = new QPushButton("C&onnect", this);
	btnConnect->setGeometry(165,115,100,35);
	btnConnect->setDefault(TRUE);
	btnConnect->show();
	connect(btnConnect, SIGNAL(clicked()), this, SLOT(slotTextChanged()));
	connect(btnConnect, SIGNAL(clicked()), this, SLOT(slotConnect()));
	
	btnCancel = new QPushButton("&Cancel", this);
	btnCancel->setGeometry(270,115,100,35);
	btnCancel->show();
	connect(btnCancel, SIGNAL(clicked()), this, SLOT(close()));
	
	btnOptions = new QPushButton("&Options...", this);
	btnOptions->setGeometry(375,115,100,35);
	btnOptions->show();
	connect(btnOptions, SIGNAL(clicked()), this, SLOT(slotTextChanged()));
	connect(btnOptions, SIGNAL(clicked()), this, SLOT(slotOptions()));

	dlgConfig = new KurdConfig(this, "kurdoptions");
}

void Kurd::slotOptions()
{
	QSize windowSize = frameSize();
	dlgConfig->move(x(),y()+windowSize.height());
	dlgConfig->show();
}


void Kurd::slotConnect()
{
	// Check if rdesktop is available
	if (KStandardDirs::findExe(QString::fromLatin1("rdesktop")).isEmpty())
	{
		KMessageBox::messageBox((QWidget *)0L, KMessageBox::Information,
		"rdesktop not found! Make sure it is in your $PATH.");
		return;
	}

	// Check if VNC is available
	if (KStandardDirs::findExe(QString::fromLatin1("vncviewer")).isEmpty())
	{
		KMessageBox::messageBox((QWidget *)0L, KMessageBox::Information,
		"vncviewer not found! Make sure it is in your $PATH.");
		return;
	}

	if (serverName->currentText() == "")
	{
		KMessageBox::messageBox((QWidget *)0L, KMessageBox::Information,
			"You must specify a valid server to connect to.");
		return;
	}

	if (serverName->currentText() == "Remote Server")
	{
		int cont;

		cont = KMessageBox::questionYesNo(this, (
			"Do you really want to connect to a terminal"
			"server/VNC Server called *Remote Server*?"
			));

		if( cont != KMessageBox::Yes )
			return;
	}

	if (dlgConfig->isUseVNC())
	{
		if (serverName->currentText().contains(":"))
		{
		}
		else
		{
		KMessageBox::messageBox((QWidget *)0L, KMessageBox::Information,
                   "When using vncviewer you must specify a valid server and display number.");
		return;
		}
	}

	KProcess *p;
	p = new KProcess;

	connect(p, SIGNAL(processExited(KProcess *)), this, SLOT(slotCheck(KProcess *)));

	if (dlgConfig->isUseVNC())
	{
		setupVNC(p);
	}
	else
	{
		setupRD(p);
	}

	*p << serverName->currentText() ;

	hide();
	p->start();
}

void Kurd::setupRD(KProcess *p)
{
	*p << "rdesktop";

	if (dlgConfig->isRd640())
		*p << "-g" << "640x480";
	if (dlgConfig->isRd800())
		*p << "-g" << "800x600";
	if (dlgConfig->isRd1024())
		*p << "-g" << "1024x768";
	if (dlgConfig->isRd1280())
		*p << "-g" << "1280x1024";
	if (dlgConfig->isWorkArea())
		*p << "-g" << "workarea";

	if (dlgConfig->isUseUsername())
		*p << "-u" << dlgConfig->currentUsername();
	if (dlgConfig->isUseDomain())
		*p << "-d" << dlgConfig->currentDomain();
	if (dlgConfig->isRdFullScreen())
		*p << "-f";
	if (dlgConfig->isColorMap())
		*p << "-C";
	if (dlgConfig->isNoOverrideKeys())
		*p << "-K";
	if (dlgConfig->isNoEncrypt())
		*p << "-e";
	if (dlgConfig->isForceBitmaps())
		*p << "-b";
	if (dlgConfig->isNoMotion())
		*p << "-m";
	if (dlgConfig->isUseHostname())
		*p << "-n" << dlgConfig->currentHostname();
}

void Kurd::setupVNC(KProcess *p)
{
	*p << "vncviewer";

	if (!dlgConfig->isShared())
		*p << "-noshared";
	if (dlgConfig->isNoRaise())
		*p << "-noraiseonbeep";
	if (dlgConfig->isTrueColor())
		*p << "-truecolor";
	if (dlgConfig->isOwnCmap())
		*p << "-owncmap";
	if (dlgConfig->isVncFullScreen())
		*p << "-fullscreen";
	if (dlgConfig->isViewOnly())
		*p << "-viewonly";
	if (dlgConfig->isX11Cursor())
		*p << "-x11cursor";
	if (dlgConfig->isUseGateway())
		*p << "-via" << dlgConfig->currentGateway();
}

void Kurd::slotCheck(KProcess *p)
{
	if (p->exitStatus() != 0)
	{
		KMessageBox::messageBox((QWidget *)0L, KMessageBox::Information,
		"Connection failed! "
		"Did you specify a valid server?");
	}

	show();
}

void Kurd::slotTextChanged()
{
	serverName->insertItem(serverName->currentText());
}
