/***************************************************************************
                          kurdconfig.cpp  -  description
                             -------------------
    begin                : Thu Feb 27 2003
    copyright            : (C) 2003 by David Monk
    email                : dmonk@purplebear.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kurdconfig.h"

KurdConfig::KurdConfig(QWidget *parent, const char *name, bool modal) : QDialog(parent, name, modal)
{
	setCaption("Kurd Options");
	setMinimumWidth(500);
	setMaximumWidth(500);
	setMinimumHeight(460);
	setMaximumHeight(460);

	useVNC = new QCheckBox("Use vncviewer", this);
	useVNC->move(10,10);
	useVNC->setMinimumWidth(200);
	QWhatsThis::add(useVNC, "Select to use vnc instead of rdesktop.");

	configTabs = new QTabWidget(this, "configtab");
	configTabs->setGeometry(5,40,490,370);
	rdTab = new QWidget(configTabs);
	vncTab = new QWidget(configTabs);
	configTabs->addTab(rdTab, "rdesktop");
	configTabs->addTab(vncTab, "vncviewer");

	connect(useVNC, SIGNAL(clicked()), this, SLOT(slotSelectTab()));

	rdOptions = new QButtonGroup(1, QGroupBox::Horizontal, "rdesktop options", rdTab);
	rdOptions->setGeometry(10,10,230,320);
		usernameBox = new QHBox(rdOptions);
		QWhatsThis::add(usernameBox, "Select and fill in username for authentication on the terminal server.");
		useUsername = new QCheckBox("Login as: ", usernameBox);
		editUsername = new QLineEdit(usernameBox);
		editUsername->setText("Administrator");
		editUsername->setDisabled(TRUE);
		domainBox = new QHBox(rdOptions);
		QWhatsThis::add(domainBox, "Select and fill in domain name for authentication.");
		useDomain = new QCheckBox("Domain: ", domainBox);
		editDomain = new QLineEdit(domainBox);
		editDomain->setDisabled(TRUE);
		hostnameBox = new QHBox(rdOptions);
		QWhatsThis::add(hostnameBox, "Select and fill in client hostname. Normally rdesktop automatically obtains the hostname of the client.");
		useHostname = new QCheckBox("Hostname: ", hostnameBox);
		editHostname = new QLineEdit(hostnameBox);
		editHostname->setDisabled(TRUE);
		rdFullScreen = new QCheckBox("Full Screen", rdOptions);
		QWhatsThis::add(rdFullScreen, "Enable fullscreen mode. This overrides the window manager and causes the rdesktop window to fully cover the current screen. Fullscreen mode can be toggled at any time using Ctrl-Alt-Enter.");
		noEncrypt = new QCheckBox("Disable encryption", rdOptions);
		QWhatsThis::add(noEncrypt, "Disable  encryption.  This option is only needed (and will only work) if you have a French version of NT TSE.");
		forceBitmaps = new QCheckBox("Force Local Bitmaps", rdOptions);
		QWhatsThis::add(forceBitmaps, "Force the server to send screen updates as bitmaps rather than using higher-level drawing operations.");
		noMotion = new QCheckBox("Send no motion events", rdOptions);
		QWhatsThis::add(noMotion, "Do not send mouse motion events. This saves bandwidth, although some Windows applications may rely on receiving mouse motion.");
		colorMap = new QCheckBox("Use private colormap", rdOptions);
		QWhatsThis::add(colorMap, "Use private colormap. This will improve colour accuracy on an 8-bit display, but rdesktop will appear in false colour when not focused.");
		noOverrideKeys = new QCheckBox("Don't override keys", rdOptions);
		QWhatsThis::add(noOverrideKeys, "Do not override window manager key bindings. By default rdesktop attempts to grab all keyboard input when it is in focus.");

	connect(useDomain, SIGNAL(clicked()), this, SLOT(slotSetEditDomain()));
	connect(useHostname, SIGNAL(clicked()), this, SLOT(slotSetEditHostname()));
	connect(useUsername, SIGNAL(clicked()), this, SLOT(slotSetEditUsername()));

	vncOptions = new QButtonGroup(1, QGroupBox::Horizontal, "vncviewer options", vncTab);
	vncOptions->setGeometry(10,10,470,320);
		shared = new QCheckBox("Request shared session", vncOptions);
		QWhatsThis::add(shared, "When connecting, specify that a shared connection is reqested. This allows you to share the desktop with other clients. If disabled, the server will either disconnect other clients or refuse your connection.");
		shared->setChecked(TRUE);
		noRaise = new QCheckBox("Don't raise on beep", vncOptions);
		QWhatsThis::add(noRaise, "By default, the viewer shows and raises its window on remote beep (bell) event. This option disables such behaviour.");
		trueColor = new QCheckBox("Use TrueColor", vncOptions);
		QWhatsThis::add(trueColor, "Try to use a TrueColor visual.");
		ownCmap = new QCheckBox("Try PseudoColor", vncOptions);
		QWhatsThis::add(ownCmap, "Try to use a PseudoColor visual and a private colormap. This allows the VNC server to control the colormap.");
		vncFullScreen = new QCheckBox("Full Screen", vncOptions);
		QWhatsThis::add(vncFullScreen, "Start in full-screen mode. Please be aware that operating in full-screen mode may confuse X window managers.");
		viewOnly = new QCheckBox("View session only", vncOptions);
		QWhatsThis::add(viewOnly, "Disable transfer of mouse and keyboard events from the client to the server.");
		x11Cursor = new QCheckBox("Show x11 cursor", vncOptions);
		QWhatsThis::add(x11Cursor, "Use a real X11 cursor with X-style cursor shape updates, instead of drawing the remote cursor on the framebuffer. This option also disables the dot cursor, and disables cursor position updates in non-fullscreen mode.");
		gatewayBox = new QHBox(vncOptions);
		QWhatsThis::add(gatewayBox, "Automatically create a SSH tunnel to the gateway machine before connection, connect to the host through that tunnel. Note that when using the -via option, the host machine name should be specified as known to the gateway machine.");
		useGateway = new QCheckBox("SSH tunnel via: ", gatewayBox);
		editGateway = new QLineEdit(gatewayBox);
		editGateway->setDisabled(TRUE);

	connect(useGateway, SIGNAL(clicked()), this, SLOT(slotSetEditGateway()));
		
	screenGeometry = new QButtonGroup(3, QGroupBox::Vertical, "screen geometry", rdTab);
	screenGeometry->setGeometry(250,10,230,100);
		rd640 = new QRadioButton( "640x480", screenGeometry);
		rd800 = new QRadioButton( "800x600", screenGeometry);
		rd1024 = new QRadioButton( "1024x768", screenGeometry);
		rd1280 = new QRadioButton( "1280x1024", screenGeometry);
		workArea = new QRadioButton("Work Area", screenGeometry);
	QWhatsThis::add(screenGeometry, "Desktop geometry. If geometry is the special 'Work Area', the geometry will be fetched from the extended window manager hints properties, from the root window.");

	btnClose = new QPushButton("&Close", this);
	btnClose->setGeometry(375,420,100,35);

	connect(btnClose, SIGNAL(clicked()), this, SLOT(hide()));
}

KurdConfig::~KurdConfig()
{
}

void KurdConfig::slotSelectTab()
{
	if (useVNC->isChecked())
		configTabs->showPage(vncTab);
	else
		configTabs->showPage(rdTab);
}

void KurdConfig::slotSetEditDomain()
{
	if (useDomain->isChecked())
	{
		editDomain->setEnabled(TRUE);
		editDomain->setFocus();
	}
	else
		editDomain->setDisabled(TRUE);
}

void KurdConfig::slotSetEditGateway()
{
	if (useGateway->isChecked())
	{
		editGateway->setEnabled(TRUE);
		editGateway->setFocus();
	}
	else
		editGateway->setDisabled(TRUE);
}

void KurdConfig::slotSetEditHostname()
{
	if (useHostname->isChecked())
	{
		editHostname->setEnabled(TRUE);
		editHostname->setFocus();
	}
	else
		editHostname->setDisabled(TRUE);
}

void KurdConfig::slotSetEditUsername()
{
	if (useUsername->isChecked())
	{
		editUsername->setEnabled(TRUE);
		editUsername->setFocus();
	}
	else
		editUsername->setDisabled(TRUE);
}
